@@ -1,4 +1,4 @@
-# Copyright 2009-2010 Yelp
+# Copyright 2009-2011 Yelp
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,8 +15,10 @@
 """
 __author__ = 'David Marin <dave@yelp.com>'
 __credits__ = ['Adam Derewicki <derwiki@yelp.com>',
+               'Brett Hoerner <brett@bretthoerner.com>',
                'Matt Jones <mattj@yelp.com>',
                'Julian Krause <juliank@yelp.com>',
                'Jimmy Retzlaff <jretz@yelp.com>',
+               'Ned Rockson <ned@tellapart.com>',
                'Paul Wais <pwais@yelp.com>']
-__version__ = '0.2.1'
+__version__ = '0.2.2'
